﻿## This file contains some of the options that can be changed to customize
## your Ren'Py game. It only contains the most common options... there
## is quite a bit more customization you can do.
##
## Lines beginning with two '#' marks are comments, and you shouldn't
## uncomment them. Lines beginning with a single '#' mark are
## commented-out code, and you may want to uncomment them when
## appropriate.

init -1 python hide:

    ## Should we enable the use of developer tools? This should be
    ## set to False before the game is released, so the user can't
    ## cheat using developer tools.

    config.developer = False

    ## These control the width and height of the screen.

    config.screen_width = 800
    config.screen_height = 600

    ## This controls the title of the window, when Ren'Py is
    ## running in a window.

    config.window_title = u"Wings"

    #########################################
    # Layouts
    
    ## This enables the use of an in-game menu that is made out of
    ## buttons.

    layout.button_menu()

    #########################################
    # Themes
    
    ## We then want to call a theme function. themes.roundrect is
    ## a theme that features the use of rounded rectangles. It's
    ## the only theme we currently support.
    ##
    ## The theme function takes a number of parameters that can
    ## customize the color scheme.

    theme.outline (inside="#FFFFFF", idle="#000000", hover="#8B8B8B", selected="#D9D9D9", insensitive="#000000", label="#000000", prompt="#000000", background="mainmenu.jpg", large_button="#FFFFFF00", text_size=22, small_text_size=16)


    style.gm_root.background = "gamemenu.jpg"


    #########################################
    ## These settings let you customize the window containing the
    ## dialogue and narration, by replacing it with an image.

    ## The background of the window. In a Frame, the two numbers
    ## are the size of the left/right and top/bottom borders,
    ## respectively.


    
    
    
    
   
    

    


    

    ## Margin is space surrounding the window, where the background
    ## is not drawn.


    ## Padding is space inside the window, where the background is
    ## drawn.


    ## This is the minimum height of the window, including the margins
    ## and padding.

    


    
    style.default.size = 20    
    
    


    #########################################
    ## This lets you change the placement of the main menu.

    ## The way placement works is that we find an anchor point
    ## inside a displayable, and a position (pos) point on the
    ## screen. We then place the displayable so the two points are
    ## at the same place.

    ## An anchor/pos can be given as an integer or a floating point
    ## number. If an integer, the number is interpreted as a number
    ## of pixels from the upper-left corner. If a floating point,
    ## the number is interpreted as a fraction of the size of the
    ## displayable or screen.

    style.mm_menu_frame.xpos = 0.75
    style.mm_menu_frame.xanchor = 0.5
    style.mm_menu_frame.ypos = 0.70
    style.mm_menu_frame.yanchor = 0.5



    #########################################
    ## These let you customize the default font used for text in Ren'Py.

    ## The file containing the default font.

    style.default.font = "gnights.TTF"

    ## The default size of text.

    style.default.size = 30

    ## Note that these only change the size of some of the text. Other
    ## buttons have their own styles.


    #########################################
    ## These settings let you change some of the sounds that are used by
    ## Ren'Py.

    ## Set this to False if the game does not have any sound effects.

    config.has_sound = True

    ## Set this to False if the game does not have any music.

    config.has_music = True

    ## Set this to False if the game does not have voicing.

    config.has_voice = False

    ## Sounds that are used when button and imagemaps are clicked.

    

    ## Sounds that are used when entering and exiting the game menu.

    # config.enter_sound = "click.wav"
    # config.exit_sound = "click.wav"

    ## A sample sound that can be played to check the sound volume.

    # config.sample_sound = "click.wav"

    ## Music that is played while the user is at the main menu.

    


    #########################################
    ## Help.

    ## This lets you configure the help option on the Ren'Py menus.
    ## It may be:
    ## - A label in the script, in which case that label is called to
    ##   show help to the user.
    ## - A file name relative to the base directory, which is opened in a
    ##   web browser.
    ## - None, to disable help.   
    config.help = None


    #########################################
    ## Transitions.

    ## Used when entering the game menu from the game.
    config.enter_transition = squares

    ## Used when exiting the game menu to the game.
    config.exit_transition = squares

    ## Used between screens of the game menu.
    config.intra_transition = squares

    ## Used when entering the game menu from the main menu.
    config.main_game_transition = dissolve

    ## Used when returning to the main menu from the game.
    config.game_main_transition = squares

    ## Used when entering the main menu from the splashscreen.
    config.end_splash_transition = dissolve

    ## Used when entering the main menu after the game has ended.
    config.end_game_transition = dissolve

    ## Used when a game is loaded.
    config.after_load_transition = dissolve

    ## Used when the window is shown.
    config.window_show_transition = dissolve

    ## Used when the window is hidden.
    config.window_hide_transition = dissolve


    #########################################
    ## This is the name of the directory where the game's data is
    ## stored. (It needs to be set early, before any other init code
    ## is run, so the persisten information can be found by the init code.)
python early:
    config.save_directory = "Wings"

init -1 python hide:
    #########################################
    ## Default values of Preferences.

    ## Note: These options are only evaluated the first time a
    ## game is run. To have them run a second time, delete
    ## game/saves/persistent

    ## Should we start in fullscreen mode?

    config.default_fullscreen = False

    ## The default text speed in characters per second. 0 is infinite.

    config.default_text_cps = 65

    #########################################
    ## More customizations can go here.
    
    config.main_menu = [
        (u"Start", "start", "True"),
        (u"Bookmarks", _intra_jumps("load_screen", "main_game_transition"), "True"),
        (u"Author's Notes", _intra_jumps("afterword", "main_game_transition"), "True"),
        (u"Options", _intra_jumps("preferences_screen", "main_game_transition"), "True"),
        (u"Quit", ui.jumps("_quit"), "True")
        ]
    

    config.game_menu = [
        ( None, u"Back", ui.jumps("_return"), 'True'),
        ( "Preferences", u"Options", _intra_jumps("preferences_screen", "intra_transition"), 'True' ),
        ( "save", u"Bookmark", _intra_jumps("save_screen", "intra_transition"), 'not main_menu' ),
        ( "load", u"Load", _intra_jumps("load_screen", "intra_transition"), 'True'),
        ( None, u"Title", ui.callsinnewcontext("_main_menu_prompt"), 'not main_menu' ),
        ( None, u"Exit", ui.callsinnewcontext("_quit_prompt"), 'True' ),
        ]

